============================
Designing Executable Scripts
============================

TODO: Describe the how to create the executables, which output is expected, 
and which output is not expected. Also, give examples of print functions in 
common languages.
